@@ -673,6 +673,16 @@ unless(caller){
         s = s.replace('"', r'\"')
         s = s.replace('$', r'\$')
         s = s.replace('@', r'\@')
+        try:
+            dummy = unicode(s, 'ascii')
+        except UnicodeDecodeError:
+            # convert byte string to unicode, escape unicode characters and
+            # convert string back to ascii
+            s = s.decode('utf8')
+            s = s.encode('unicode-escape')
+            # convert Python style to Perl style
+            s = re.sub(r'\\u([0-9]{4})\b', r'\\N{U+\1}', s)
+
         if self._use_gettext and translate:
             return '_T("%s")' % s
         else:
@@ -701,18 +711,20 @@ unless(caller){
         return '#$self->%s' % name
 
     def _format_classattr(self, obj):
-        if not obj:
-            return ''
-        if not hasattr(obj, 'name'):
-            return ''
-        if obj.name.startswith('$self->'):
+        res = BaseCodeWriter._format_classattr(self, obj)
+        if not res:
+            return res
+        elif obj.name.startswith('$self->'):
             return obj.name
-        if not re.match('[a-zA-Z]', obj.name):
+        elif obj.name.startswith('$'):
+            return obj.name
+        # spacer.name is "<width>, <height>" already
+        elif obj.klass == 'spacer':
             return obj.name
         # Perl stores sizers always in class attributes
-        if self.test_attribute(obj) or obj.in_sizers:
-            return "$self->{%s}" % obj.name
-        return "$%s" % obj.name
+        elif self.test_attribute(obj) or obj.in_sizers:
+            return '$self->{%s}' % obj.name
+        return '$%s' % obj.name
 
     def _format_import(self, klass):
         stmt = 'use %s;\n' % klass
