@@ -651,12 +651,16 @@ def %(handler)s(self, event):  # wxGlade: %(klass)s.<event_handler>
         else:
             s = s.replace('\\', r'\\')  # just quote the backslashes
         try:
-            unicode(s, 'ascii')
+            dummy = unicode(s, 'ascii')
             if self._use_gettext and translate:
                 return '_("%s")' % s
             else:
                 return '"%s"' % s
         except UnicodeDecodeError:
+            # convert byte string to unicode, escape unicode characters and
+            # convert string back to ascii
+            s = s.decode('utf8')
+            s = s.encode('unicode-escape')
             if self._use_gettext and translate:
                 return '_(u"%s")' % s
             else:
@@ -672,20 +676,17 @@ def %(handler)s(self, event):  # wxGlade: %(klass)s.<event_handler>
         return '#self.%s' % name
 
     def _format_classattr(self, obj):
-        if not obj:
-            return ''
-        if not hasattr(obj, 'name'):
-            return ''
-        if obj.name.startswith('self.'):
+        res = BaseCodeWriter._format_classattr(self, obj)
+        if not res:
+            return res
+        elif obj.name.startswith('self.'):
             return obj.name
         # spacer.name is "<width>, <height>" already, but wxPython expect
         # a tuple instead of two single values
-        if obj.klass == 'spacer':
+        elif obj.klass == 'spacer':
             return '(%s)' % obj.name
-        if not re.match('[a-zA-Z]', obj.name):
-            return obj.name
-        if self.test_attribute(obj):
-            return "self.%s" % obj.name
+        elif self.test_attribute(obj):
+            return 'self.%s' % obj.name
         return obj.name
 
     def _format_import(self, klass):
