@@ -1,15 +1,209 @@
-# edit_sizers.py: hierarchy of Sizers supported by wxGlade
-# 
-# Copyright (c) 2002-2007 Alberto Griggio <agriggio@users.sourceforge.net>
-#
-# License: MIT (see license.txt)
-# THIS PROGRAM COMES WITH NO WARRANTY
+"""
+Hierarchy of Sizers supported by wxGlade
 
+@copyright: 2002-2007 Alberto Griggio <agriggio@users.sourceforge.net>
+@license: MIT (see license.txt) - THIS PROGRAM COMES WITH NO WARRANTY
+"""
+
+# import general python modules
+import math
+import re
+
+# import project modules
 import wx
 from widget_properties import *
 from tree import Tree, WidgetTree
-import common, config, misc
-import math, re
+import common
+import config
+import misc
+
+
+class BaseSizerBuilder(object):
+    """\
+    Language independen base class for all sizer builders
+    
+    @cvar klass: Sizer class
+    @type klass: String
+    
+    @cvar language: Language to generate the code for
+    @type language: String
+    
+    @cvar init_stmt: Statements to generate the sizer from;
+                     lines have to end with a newline character
+    @type init_stmt: List of strings
+    
+    @cvar tmpl_AddGrowableRow: Template for wxFlexGridSizer to set growable
+                               rows
+    @type tmpl_AddGrowableRow: String
+    
+    @cvar tmpl_AddGrowableCol: Template for wxFlexGridSizer to set growable
+                               columns
+    @type tmpl_AddGrowableCol: String
+    
+    @cvar tmpl_SetSizer: Template to call SetSizer()
+    @type tmpl_SetSizer: String
+    
+    @cvar tmpl_Fit: Template to call Fit()
+    @type tmpl_Fit: String
+
+    @cvar tmpl_StaticBox: Template for staticbox name used in combination with
+                          wxStaticBoxSizer.
+    @type tmpl_StaticBox: String
+
+    @cvar tmpl_SetSizeHints: Template to set the size hints
+    @type tmpl_SetSizeHints: String
+    
+    @ivar codegen: Language specific code generator
+    @type codegen: Instance of L{codegen.BaseCodeWriter}
+    
+    @ivar props_get_code: Properties to replace in L{init_stmt}
+    @type props_get_code: Dictionary
+    """
+
+    init_stmt = []
+
+    klass = ''
+    language = None
+
+    tmpl_SetSizer = ''
+    tmpl_Fit = ''
+    tmpl_SetSizeHints = ''
+    tmpl_StaticBox = ''
+    tmpl_AddGrowableRow = ''
+    tmpl_AddGrowableCol = ''
+    
+
+    def __init__(self):
+        """\
+        Initialise sizer builder
+        """
+        self.props_get_code = {}
+        self.codegen = common.code_writers[self.language]
+
+    def _get_wparent(self, obj):
+        """\
+        Return the parent widget or a reference to it.
+        
+        @rtype: String
+        """
+        raise NotImplementedError
+        
+    def _get_code(self, obj):
+        """\
+        Generates the language specific code for sizer specified in L{klass}
+        """
+        if not self.init_stmt:
+            return [], [], []
+
+        init = []
+        layout = []
+
+        # append default properties
+        self.props_get_code['sizer_name'] = obj.name
+        self.props_get_code['klass'] = self.codegen.cn(self.klass)
+        self.props_get_code['wxIDANY'] = self.codegen.cn('wxID_ANY')
+        self.props_get_code['parent_widget'] = self._get_wparent(obj)
+
+        self.props_get_code['sizer_name'] = \
+            self.codegen._format_classattr(obj)
+
+        if self.klass == 'wxStaticBoxSizer' and self.tmpl_StaticBox:
+            self.props_get_code['staticbox_name'] = \
+                self.tmpl_StaticBox % obj.name
+
+        # generate init lines from init_stmt filled with props_get_code
+        for line in self.init_stmt:
+            init.append(line % self.props_get_code)
+
+        # generate layout lines
+        if obj.is_toplevel:
+            layout.append(self.tmpl_SetSizer % self.props_get_code)
+            if not obj.parent.properties.has_key('size') and \
+                   obj.parent.is_toplevel:
+                layout.append(self.tmpl_Fit % self.props_get_code)
+            if obj.parent.properties.get('sizehints', False):
+                layout.append(self.tmpl_SetSizeHints % self.props_get_code)
+            
+        return init, [], layout
+        
+    def get_code(self, obj):
+        """\
+        Generates the language specific code for sizer specified in L{klass}
+        """
+        if self.klass == 'wxBoxSizer':
+            return self.get_code_wxBoxSizer(obj)
+        if self.klass == 'wxStaticBoxSizer':
+            return self.get_code_wxStaticBoxSizer(obj)
+        if self.klass == 'wxGridSizer':
+            return self.get_code_wxGridSizer(obj)
+        if self.klass == 'wxFlexGridSizer':
+            return self.get_code_wxFlexGridSizer(obj)            
+        return self._get_code(obj)
+        
+    def get_code_wxStaticBoxSizer(self, obj):
+        """\
+        Set sizer specific properties and generate the code
+        """
+        self.props_get_code.clear()
+        self.props_get_code['orient'] = self.codegen.cn(
+            obj.properties.get('orient', 'wxHORIZONTAL')
+            )
+        self.props_get_code['label'] = self.codegen.quote_str(
+            obj.properties.get('label', '')
+            )
+        self.props_get_code['wxStaticBox'] = self.codegen.cn('wxStaticBox')
+        return self._get_code(obj)
+        
+    def get_code_wxBoxSizer(self, obj):
+        """\
+        Set sizer specific properties and generate the code
+        """
+        self.props_get_code.clear()
+        self.props_get_code['orient'] = self.codegen.cn(
+            obj.properties.get('orient', 'wxHORIZONTAL')
+            )
+        return self._get_code(obj)      
+    
+    def get_code_wxGridSizer(self, obj):
+        """\
+        Set sizer specific properties and generate the code
+        """
+        self.props_get_code.clear()
+        self.props_get_code['rows'] = obj.properties.get('rows', '0')
+        self.props_get_code['cols'] = obj.properties.get('cols', '0')
+        self.props_get_code['vgap'] = obj.properties.get('vgap', '0')
+        self.props_get_code['hgap'] = obj.properties.get('hgap', '0')
+        return self._get_code(obj)
+
+    def get_code_wxFlexGridSizer(self, obj):
+        """\
+        Set sizer specific properties and generate the code
+        """
+        result = self.get_code_wxGridSizer(obj)
+        
+        # convert tuple to list
+        result = list(result)
+        
+        # extract layout lines
+        layout = result[-1]
+        del result[-1]
+        
+        props = obj.properties
+        if props.has_key('growable_rows'):
+            for row in props['growable_rows'].split(','):
+                self.props_get_code['row'] = row.strip()
+                layout.append(self.tmpl_AddGrowableRow % self.props_get_code)
+        if props.has_key('growable_cols'):
+            for col in props['growable_cols'].split(','):
+                self.props_get_code['col'] = col.strip()
+                layout.append(self.tmpl_AddGrowableCol % self.props_get_code)
+
+        # reappend layout lines
+        result.append(layout)
+        return result
+
+# end of class BaseSizerBuilder
+
 
 class SizerSlot:
     "a window to represent a slot in a sizer"
@@ -446,6 +640,8 @@ class InsertDialog(wx.Dialog):
         wx.Dialog.__init__(self, None, -1, _("Select a position"))
         self.pos = 0
         pos_prop = SpinProperty(self, 'position', self, r=(0, max_val), label=_("position"))
+        pos_prop.spin.SetFocus()
+        pos_prop.spin.SetSelection(-1, -1)        
         szr = wx.BoxSizer(wx.VERTICAL)
         szr.Add(pos_prop.panel, 0, wx.ALL|wx.EXPAND, 5)
         szr2 = wx.BoxSizer(wx.HORIZONTAL)
@@ -529,6 +725,7 @@ class SizerBase(Sizer):
     def __init__(self, name, klass, window, toplevel=True, show=True,
                  menu=None):
         Sizer.__init__(self, window)
+        self.attribute = 0
         self.id = wx.NewId()
         self.name = name
         self.klass = klass
@@ -600,7 +797,8 @@ class SizerBase(Sizer):
 
         self.access_functions = {
             'name' : (lambda : self.name, self.set_name),
-            'class' : (lambda : self.klass, self.change) #lambda v: None)
+            'class': (lambda: self.klass, self.change),
+            'attribute': (self.get_attribute, self.set_attribute),
             }
         if not self.toplevel:
             self.access_functions['option'] = (self.get_option, self.set_option)
@@ -612,6 +810,16 @@ class SizerBase(Sizer):
         #self.klass_prop = TextProperty(self, 'class', None, readonly=True)
         dialog = SizerClassDialog(self, None)
         self.klass_prop = DialogProperty(self, 'class', None, dialog, label=_('class'))
+
+        self.attr_prop = CheckBoxProperty(
+            self,
+            'attribute',
+            None,
+            _('Store as attribute'),
+            write_always=False,
+            )
+        self.properties['attribute'] = self.attr_prop
+
         if not self.toplevel:
             prop = self.sizer_properties = {}
 
@@ -642,6 +850,12 @@ class SizerBase(Sizer):
         wx.CallAfter(self.sizer.change_item_pos, 
                          self, min(value + 1, len(self.sizer.children) - 1))
 
+    def get_attribute(self):
+        return self.attribute
+
+    def set_attribute(self, value):
+        self.attribute = int(value)
+
     def update_pos(self, value):
         #print 'update pos', self.name, value
         self.sizer_properties['pos'].set_value(value-1)
@@ -662,8 +876,10 @@ class SizerBase(Sizer):
         self.name_prop.display(panel)
         self.klass_prop.display(panel)
         self.klass_prop.text.SetEditable(False)
+        self.attr_prop.display(panel)
         sizer_tmp.Add(self.name_prop.panel, 0, wx.EXPAND)
         sizer_tmp.Add(self.klass_prop.panel, 0, wx.EXPAND)
+        sizer_tmp.Add(self.attr_prop.panel, 0, wx.EXPAND)
         if not self.toplevel:
             prop = self.sizer_properties
             prop['pos'].display(panel)
@@ -678,6 +894,9 @@ class SizerBase(Sizer):
             # button to Fit parent
             FIT_ID = wx.NewId()
             self.fit_btn = wx.Button(panel, FIT_ID, _('Fit parent'))
+            self.fit_btn.SetToolTip(wx.ToolTip(
+                _('Sizes the window so that it fits around its subwindows')
+                ))
             wx.EVT_BUTTON(self.fit_btn, FIT_ID, self.fit_parent)
             sizer_tmp.Add(self.fit_btn, 0, wx.ALL|wx.EXPAND, 5)
         panel.SetAutoLayout(True)
@@ -715,8 +934,7 @@ class SizerBase(Sizer):
             try:
                 common.app_tree.refresh_name(self.node, oldname)
             except AttributeError:
-                import traceback
-                traceback.print_exc()
+                common.message.exception(_('Internal Error'))
             self.property_window.SetTitle(_('Properties - <%s>') % self.name)
     set_name_pattern = re.compile('^[a-zA-Z_]+[\w0-9]*$')
             
@@ -794,8 +1012,7 @@ class SizerBase(Sizer):
             self.children[pos] = SizerItem(item, pos, option, flag, border,
                                            size)
         except IndexError: # this shouldn't happen!
-            import traceback
-            traceback.print_exc()
+            common.message.exception(_('Internal Error'))
             print self.children, pos
             raise SystemExit
 
@@ -854,7 +1071,7 @@ class SizerBase(Sizer):
                 #*item.widget.GetBestSize())
             #self.widget.SetItemMinSize(item.widget, w, h)
         except Exception:
-            #import traceback; traceback.print_exc()
+            #common.message.exception(_('Internal Error'))
             pass
         if force_layout: self.layout() # update the layout of self
 
@@ -884,7 +1101,7 @@ class SizerBase(Sizer):
         try:
             item = self.children[pos]
         except IndexError: # this shouldn't happen
-            import traceback; traceback.print_exc()
+            common.message.exception(_('Internal Error'))
             raise SystemExit
         if option is not None:
             option = int(option)
@@ -1271,10 +1488,11 @@ class EditBoxSizer(SizerBase):
                  toplevel=True, show=True):
         SizerBase.__init__(self, name, 'wxBoxSizer', window, toplevel, show)
         self.access_functions['orient'] = (self.get_orient, self.set_orient)
-        self.properties = {'orient': HiddenProperty(self, 'orient',
-                                                    (orient==wx.HORIZONTAL and
-                                                     'wxHORIZONTAL' or
-                                                     'wxVERTICAL')) }
+        self.properties['orient'] = HiddenProperty(
+            self,
+            'orient',
+            (orient == wx.HORIZONTAL and 'wxHORIZONTAL' or 'wxVERTICAL'),
+            )
         class Dummy:
             widget = None
             name = ""
@@ -1361,10 +1579,11 @@ class EditStaticBoxSizer(SizerBase):
         SizerBase.__init__(self, name, 'wxStaticBoxSizer', window, toplevel,
                            show)
         self.access_functions['orient'] = (self.get_orient, self.set_orient)
-        self.properties['orient'] = HiddenProperty(self, 'orient',
-                                                   (orient==wx.HORIZONTAL and
-                                                    'wxHORIZONTAL' or
-                                                    'wxVERTICAL'))
+        self.properties['orient'] = HiddenProperty(
+            self,
+            'orient',
+            (orient==wx.HORIZONTAL and 'wxHORIZONTAL' or 'wxVERTICAL'),
+            )
         class Dummy: widget = None
         # add to self.children the SizerItem for self._btn
         self.children = [SizerItem(Dummy(), 0, 0, wx.EXPAND)]
@@ -1599,7 +1818,16 @@ class GridSizerBase(SizerBase):
                   'cols': SpinProperty(self, 'cols', None, label=_("cols")),
                   'hgap': SpinProperty(self, 'hgap', None, label=_("hgap")),
                   'vgap': SpinProperty(self, 'vgap', None, label=_("vgap")) }
-        self.properties = props
+        props['rows'].set_tooltip(_('Numbers of sizer rows'))
+        props['cols'].set_tooltip(_('Numbers of sizer columns'))
+        props['vgap'].set_tooltip(
+                _('Vertical extra space between all children')
+                )
+        props['hgap'].set_tooltip(
+                _('Horizontal extra space between all children')
+                )
+
+        self.properties.update(props)
 
     def create_properties(self):
         SizerBase.create_properties(self)
@@ -2134,24 +2362,39 @@ def grid_builder(parent, sizer, pos, number=[1], show=True):
             self.cols = SpinProperty(self, 'cols', self, label=_("cols"))
             self.vgap = SpinProperty(self, 'vgap', self, label=_("vgap"))
             self.hgap = SpinProperty(self, 'hgap', self, label=_("hgap"))
-            self.flex = wx.CheckBox(self, -1, '')
+            self.rows.set_tooltip(_('Numbers of sizer rows'))
+            self.cols.set_tooltip(_('Numbers of sizer columns'))
+            self.vgap.set_tooltip(
+                _('Vertical extra space between all children')
+                )
+            self.hgap.set_tooltip(
+                _('Horizontal extra space between all children')
+                )
+            self.rows.spin.SetFocus()
+            self.rows.spin.SetSelection(-1, -1)
+
+            self.flex = CheckBoxProperty(
+                self,
+                'flex',
+                self,
+                _('Flexible'),
+                write_always=True,
+                )
+            self.flex.set_tooltip(
+                _('Create a wxFlexGridSizer instead of a wxGridSizer')
+                )
 
             self.rows.set_value(3)
             self.cols.set_value(3)
             self.vgap.set_value(0)
             self.hgap.set_value(0)
 
-            szr = wx.BoxSizer(wx.HORIZONTAL)
-            szr.Add(wx.StaticText(self, -1, _('Flexible')), 2,
-                    wx.ALL|wx.ALIGN_CENTER_VERTICAL, 4)
-            szr.Add(self.flex, 5, wx.ALL, 4)
-
             sizer = wx.BoxSizer(wx.VERTICAL)
             sizer.Add(self.rows.panel, 0, wx.LEFT|wx.RIGHT|wx.TOP|wx.EXPAND, 10)
             sizer.Add(self.cols.panel, 0, wx.LEFT|wx.RIGHT|wx.EXPAND, 10)
             sizer.Add(self.vgap.panel, 0, wx.LEFT|wx.RIGHT|wx.EXPAND, 10)
             sizer.Add(self.hgap.panel, 0, wx.LEFT|wx.RIGHT|wx.EXPAND, 10)
-            sizer.Add(szr, 0, wx.LEFT|wx.RIGHT|wx.EXPAND, 10)
+            sizer.Add(self.flex.panel, 0, wx.LEFT|wx.RIGHT|wx.EXPAND, 10)
             szr = wx.BoxSizer(wx.HORIZONTAL)
             btn = wx.Button(self, wx.ID_OK, _('OK'))
             btn.SetDefault()            
@@ -2180,9 +2423,12 @@ def grid_builder(parent, sizer, pos, number=[1], show=True):
         number[0] += 1
         name = 'grid_sizer_%d' % number[0]
     topl = True
-    if dialog.flex.GetValue(): constructor = EditFlexGridSizer
-    else: constructor = EditGridSizer
-    if sizer is not None: topl = False
+    if dialog.flex.get_value():
+        constructor = EditFlexGridSizer
+    else:
+        constructor = EditGridSizer
+    if sizer is not None:
+        topl = False
     sz = constructor(name, parent, rows, cols, vgap, hgap, topl)
     if sizer is not None:
         sizer.add_item(sz, pos, 1, wx.EXPAND)
