@@ -1,36 +1,56 @@
-# edit_windows.py: base classes for windows used by wxGlade
-# 
-# Copyright (c) 2002-2007 Alberto Griggio <agriggio@users.sourceforge.net>
-#
-# License: MIT (see license.txt)
-# THIS PROGRAM COMES WITH NO WARRANTY
+"""
+Base classes for windows used by wxGlade
 
-import wx
-from widget_properties import *
-import math, misc, common, config
+@copyright: 2002-2007 Alberto Griggio <agriggio@users.sourceforge.net>
+@license: MIT (see license.txt) - THIS PROGRAM COMES WITH NO WARRANTY
+"""
+
+# import general python modules
+import math
 import re
+import wx
 
-# ALB 2004-12-05: event handling support
+try: set
+except NameError: from sets import Set as set
+
+# import project modules
+from widget_properties import *
+import misc
+import common
+import config
+
+# event handling support
 from events_mixin import EventsMixin
 
-
 class EditBase(EventsMixin):
     """\
     Base class of every window available in the builder.
+
+    @ivar custom_class: If true, the user can chage the value of the
+                        'class' property
+    @ivar name:  Name of the object
+    @ivar klass: Name of the object's class
+    @ivar property_window: Widget inside which Properties of this object are
+                           displayed
+    @ivar widget: This is the reference to the actual wxWindow widget; it is
+                  created only if needed, i.e. when it should become visible
+    @ivar _rmenu: Popup menu
     """
     def __init__(self, name, klass, parent, id, property_window, show=True,
                  custom_class=True):
-        # property_window: widget inside which Properties of this object
-        #                  are displayed
-        # name: name of the object
-        # klass: name of the object's class
-        # custom_class: if true, the user can chage the value of the 'class'
-        #               property
-        
-        # dictionary of properties relative to this object; the properties that
-        # control the layout (i.e. the behaviour when inside a sizer) are not
-        # contained here, but in a separate list (see ManagedBase)
-        # the keys of the dict are the names of the properties
+        """\
+        Dictionary of properties relative to this object; the properties that
+        control the layout (i.e. the behaviour when inside a sizer) are not
+        contained here, but in a separate list (see L{ManagedBase})
+        the keys of the dict are the names of the properties
+
+        @param property_window: Widget inside which Properties of this object
+                                are displayed
+        @param name:  Name of the object
+        @param klass: Name of the object's class
+        @param custom_class: If true, the user can chage the value of the
+                            'class' property
+        """       
         self.properties = {}
         self.property_blocking = {}
         self.parent = parent
@@ -51,6 +71,9 @@ class EditBase(EventsMixin):
         # these two properties are special and are not listed in
         # 'self.properties'
         self.name_prop = TextProperty(self, 'name', None, label=_("name"))
+        self.name_prop.tooltip = _("Name of the variable for assigning " \
+                                   "the reference to the created widget " \
+                                   "instance.")
         self.klass_prop = TextProperty(self, 'class', None,
                                        readonly=not custom_class, label=_("class"))
         if custom_class:
@@ -77,7 +100,7 @@ A comma-separated list of custom base classes. The first will be invoked \
 with the same parameters as this class, while for the others the default \
 constructor will be used. You should probably not use this if \
 "overwrite existing sources" is not set.""")
-            
+
         self.notebook = None
         self.property_window = property_window
 
@@ -106,7 +129,7 @@ constructor will be used. You should probably not use this if \
             self.create_widget()
             self.finish_widget_creation()
         if self.widget: self.widget.Show(yes)
-    
+
     def create_widget(self):
         """\
         Initializes self.widget and shows it
@@ -138,7 +161,7 @@ constructor will be used. You should probably not use this if \
         if self.widget and not self._dont_destroy:
             self.widget.Destroy()
         if misc.focused_widget is self: misc.focused_widget = None
-            
+
     def create_properties(self):
         """\
         Creates the notebook with the properties of self
@@ -171,6 +194,18 @@ constructor will be used. You should probably not use this if \
             self.name_prop.set_value(self.name)
             return
         if not re.match(self.set_name_pattern, value):
+            wx.CallAfter(
+                wx.MessageBox, _(
+                'The new name "%s" contains invalid characters. The\n'
+                'old name "%s" will be retain.\n'
+                '\n'
+                'Valid characters are alphanumeric characters, minus sign\n'
+                'and the underscore. Names start always with an alphabetic\n'
+                'character or an underscore.\n'
+                '\n'
+                'Please enter a different name.') % (value, self.name),
+                _("Error"),
+                wx.OK|wx.ICON_ERROR)
             self.name_prop.set_value(self.name)
         else:
             oldname = self.name
@@ -310,8 +345,8 @@ constructor will be used. You should probably not use this if \
         try: common.app_tree.select_item(self.node)
         except AttributeError: pass
         self.widget.SetFocus()
-        
-        
+
+
     def on_set_focus(self, event):
         """\
         Event handler called when a window receives the focus: this in fact is
@@ -324,7 +359,7 @@ constructor will be used. You should probably not use this if \
 
     def get_property_handler(self, prop_name):
         """\
-        returns a custom handler function for the property 'prop_name', used
+        Returns a custom handler function for the property 'prop_name', used
         when loading this object from an xml file. handler must provide
         three methods: 'start_elem', 'end_elem' and 'char_data'
         """
@@ -333,7 +368,7 @@ constructor will be used. You should probably not use this if \
 
     def clipboard_copy(self, *args):
         """\
-        returns a copy of self to be inserted in the clipboard
+        Returns a copy of self to be inserted in the clipboard
         """
         import clipboard
         clipboard.copy(self)
@@ -353,8 +388,8 @@ constructor will be used. You should probably not use this if \
 
     def update_view(self, selected):
         """\
-        updates the widget's view to reflect its state, i.e. shows which widget
-        is currently selected; the default implementation does nothing.
+        Updates the widget's view to reflect its state, i.e. shows which
+        widget is currently selected; the default implementation does nothing.
         """
         pass
 
@@ -405,7 +440,7 @@ class WindowBase(EditBase):
         EditBase.__init__(self, name, klass, parent, id, property_window,
                           show=False)
         # 'property' id (editable by the user) 
-        self.window_id = -1
+        self.window_id = "wxID_ANY"
 
         def set_id(value):
             self.window_id = value
@@ -423,23 +458,29 @@ class WindowBase(EditBase):
         self.font = self._build_from_font(wx.SystemSettings_GetFont(
             wx.SYS_DEFAULT_GUI_FONT))
         self.font[1] = 'default'
-        
+
         self.access_functions['font'] = (self.get_font, self.set_font)
 
         # properties added 2002-08-15
         self.tooltip = ''
         self.access_functions['tooltip'] = (self.get_tooltip, self.set_tooltip)
 
-        min_x = wx.SystemSettings_GetMetric(wx.SYS_WINDOWMIN_X)
-        min_y = wx.SystemSettings_GetMetric(wx.SYS_WINDOWMIN_Y)
-        max_x = wx.SystemSettings_GetMetric(wx.SYS_SCREEN_X)
-        max_y = wx.SystemSettings_GetMetric(wx.SYS_SCREEN_Y)
-
         self._original = {'background': None, 'foreground': None,
                           'font': None}        
 
         prop = self.properties
         prop['id'] = TextProperty(self, 'id', None, can_disable=True)
+        prop['id'].tooltip = _("""\
+The "Id" property could be 
+1) a constant numeric value
+2) a predefined identifier e.g. wxID_ANY
+3) a predefined variable like a class member e.g. self.myButtonID
+4) a variable assignment e.g. self.myButtonID=?
+
+The pattern of a variable assignment is always "variable=value". The \
+value could be again a numeric value, a predefined identifier, \
+another predefined variable or "?" a shortcut for "wxNewId()". \
+""")
         prop['size'] = TextProperty(self, 'size', None, can_disable=True, label=_("size"))
         prop['background'] = ColorDialogProperty(self, "background", None, label=_("background"))
         prop['foreground'] = ColorDialogProperty(self, "foreground", None, label=_("foreground"))
@@ -453,7 +494,7 @@ class WindowBase(EditBase):
         self.access_functions['disabled'] = (self.get_disabled,
                                              self.set_disabled)
         prop['disabled'] = CheckBoxProperty(self, 'disabled', None, _('disabled'))
-        
+
         self.focused_p = False
         self.access_functions['focused'] = (self.get_focused, self.set_focused)
         prop['focused'] = CheckBoxProperty(self, 'focused', None, _('focused'))
@@ -462,7 +503,7 @@ class WindowBase(EditBase):
         self.access_functions['hidden'] = (self.get_hidden, self.set_hidden)
         prop['hidden'] = CheckBoxProperty(self, 'hidden', None, _('hidden'))
 
-        
+
 
     def finish_widget_creation(self, *args, **kwds):
         self._original['background'] = self.widget.GetBackgroundColour()
@@ -471,7 +512,7 @@ class WindowBase(EditBase):
         if not fnt.Ok():
             fnt = wx.SystemSettings_GetFont(wx.SYS_DEFAULT_GUI_FONT)
         self._original['font'] = fnt
-        
+
         prop = self.properties
         size = prop['size'].get_value()
         if size:
@@ -515,24 +556,20 @@ class WindowBase(EditBase):
 
     def create_properties(self):
         EditBase.create_properties(self)
-        min_x = wx.SystemSettings_GetMetric(wx.SYS_WINDOWMIN_X)
-        min_y = wx.SystemSettings_GetMetric(wx.SYS_WINDOWMIN_Y)
-        max_x = wx.SystemSettings_GetMetric(wx.SYS_SCREEN_X)
-        max_y = wx.SystemSettings_GetMetric(wx.SYS_SCREEN_Y)
 
         panel = self._common_panel
-            
+
         prop = self.properties
         prop['id'].display(panel)
         prop['size'].display(panel)
-        
+
         prop['background'].display(panel) 
         prop['foreground'].display(panel)
-        try: prop['font'].display(panel) 
-        except KeyError: pass
-        # new properties 2002-08-15
+        try:
+            prop['font'].display(panel) 
+        except KeyError:
+            pass
         prop['tooltip'].display(panel)
-        # new properties 2003-05-15
         prop['disabled'].display(panel)
         prop['focused'].display(panel)
         prop['hidden'].display(panel)
@@ -546,13 +583,42 @@ class WindowBase(EditBase):
         sizer_tmp.Add(prop['size'].panel, 0, wx.EXPAND)
         sizer_tmp.Add(prop['background'].panel, 0, wx.EXPAND)
         sizer_tmp.Add(prop['foreground'].panel, 0, wx.EXPAND)
-        try: sizer_tmp.Add(prop['font'].panel, 0, wx.EXPAND)
-        except KeyError: pass
+        try:
+            sizer_tmp.Add(prop['font'].panel, 0, wx.EXPAND)
+        except KeyError:
+            pass
         sizer_tmp.Add(prop['tooltip'].panel, 0, wx.EXPAND)
         sizer_tmp.Add(prop['disabled'].panel, 0, wx.EXPAND)
         sizer_tmp.Add(prop['focused'].panel, 0, wx.EXPAND)
         sizer_tmp.Add(prop['hidden'].panel, 0, wx.EXPAND)
-        
+
+        # add a note if the widget don't support all supported wx versions
+        all_versions = set(common.app_tree.app.all_supported_versions)
+        supported = set(
+            [misc.format_for_version(version) \
+             for version in getattr(self, 'supported_by', [])]
+            )
+        not_supported = all_versions.difference(supported)
+        # hint text only if we have support information (supported_by) and
+        # not all versions are supported (not_supported)
+        if supported and not_supported:
+            text_supported = ', '.join(supported)
+            text_not_supported = ', '.join(not_supported)
+            note = wx.StaticText(
+                panel,
+                -1, 
+                _("This widget is only supported for wx %s") % \
+                text_supported
+                )
+            note.SetToolTip(wx.ToolTip(
+                _("This widgets is supported for wx versions %(supported)s "
+                  "and not at %(not_supported)s." ) % {
+                    'supported': text_supported,
+                    'not_supported': text_not_supported,
+                    }
+                ))
+            sizer_tmp.Add(note, 0, wx.ALL | wx.EXPAND, 3)        
+
         panel.SetAutoLayout(1)
         panel.SetSizer(sizer_tmp)
         sizer_tmp.Layout()
@@ -564,7 +630,6 @@ class WindowBase(EditBase):
         panel.SetScrollbars(1, 5, 1, int(math.ceil(h/5.0)))
 
 
-
     def on_size(self, event):
         """\
         update the value of the 'size' property
@@ -625,7 +690,7 @@ class WindowBase(EditBase):
                 self.properties['background'].set_value(self.get_background())
                 return
         self.widget.Refresh()
-            
+
     def set_foreground(self, value):
         oldval = self.foreground
         self.foreground = value
@@ -647,7 +712,7 @@ class WindowBase(EditBase):
 
     def get_font(self):
         return str(self.font)
-    
+
     def _build_from_font(self, font):
         families = FontDialogProperty.font_families_from
         styles = FontDialogProperty.font_styles_from
@@ -668,7 +733,7 @@ class WindowBase(EditBase):
             f = wx.Font(int(value[0]), families[value[1]], styles[value[2]],
                        weights[value[3]], int(value[4]), value[5])
         except:
-            #import traceback; traceback.print_exc()
+            #common.message.exception(_('Internal Error'))
             self.properties['font'].set_value(self.get_font())
         else:
             self.font = value
@@ -791,7 +856,7 @@ class ManagedBase(WindowBase):
         self.option = 0
         self.flag = 0
         self.border = 0
-        
+
         self.sizer = sizer
         self.pos = pos
         self.access_functions['option'] = (self.get_option, self.set_option)
@@ -822,7 +887,7 @@ class ManagedBase(WindowBase):
         from layout_option_property import LayoutOptionProperty, \
              LayoutPosProperty
         szprop['option'] = LayoutOptionProperty(self, sizer)
-        
+
         szprop['flag'] = CheckListProperty(self, 'flag', None, flag_labels)
         szprop['border'] = SpinProperty(self, 'border', None, 0, (0, 1000), label=_('border'))
 ##         pos_p = szprop['pos'] = SpinProperty(self, 'pos', None, 0, (0, 1000))
@@ -854,11 +919,6 @@ class ManagedBase(WindowBase):
         panel = wx.ScrolledWindow(
             self.notebook, -1, style=wx.TAB_TRAVERSAL|wx.FULL_REPAINT_ON_RESIZE)
 
-        min_x = wx.SystemSettings_GetMetric(wx.SYS_WINDOWMIN_X)
-        min_y = wx.SystemSettings_GetMetric(wx.SYS_WINDOWMIN_Y)
-        max_x = wx.SystemSettings_GetMetric(wx.SYS_SCREEN_X)
-        max_y = wx.SystemSettings_GetMetric(wx.SYS_SCREEN_Y)
-
         szprop = self.sizer_properties
         szprop['pos'].display(panel)
         szprop['option'].display(panel)
@@ -878,13 +938,13 @@ class ManagedBase(WindowBase):
         w, h = panel.GetClientSize()
         self.notebook.AddPage(panel, _("Layout"))
         panel.SetScrollbars(1, 5, 1, int(math.ceil(h/5.0)))
-        
+
     def update_view(self, selected):
         if self.sel_marker: self.sel_marker.Show(selected)
 
     def on_move(self, event):
         self.sel_marker.update()
-        
+
     def on_size(self, event):
         old = self.size
         WindowBase.on_size(self, event)
@@ -947,7 +1007,7 @@ class ManagedBase(WindowBase):
                 size = list(self.widget.GetBestSize())
             self.sizer.set_item(self.pos, flag=flags, size=size)
         except AttributeError, e:
-            import traceback; traceback.print_exc()
+            common.message.exception(_('Internal Error'))
 
     def set_border(self, value):
         self.border = int(value)
@@ -966,7 +1026,7 @@ class ManagedBase(WindowBase):
             if h == -1: h = self.widget.GetSize()[1]
             self.sizer.set_item(self.pos, border=int(value), size=(w, h))
         except AttributeError, e:
-            import traceback; traceback.print_exc()
+            common.message.exception(_('Internal Error'))
 
     def get_option(self):
         return self.option
@@ -1005,7 +1065,7 @@ class ManagedBase(WindowBase):
         """setter for the 'pos' property: calls self.sizer.change_item_pos"""
         self.sizer.change_item_pos(self, min(value + 1,
                                              len(self.sizer.children) - 1))
-        
+
     def update_pos(self, value):
         """\
         called by self.sizer.change_item_pos to update the item's position
@@ -1019,7 +1079,12 @@ class ManagedBase(WindowBase):
 
 
 class PreviewMixin:
-    """Mixin class used to add preview to a widget"""
+    """\
+    Mixin class used to add preview to a widget
+
+    @ivar preview_button: Button to show or close the preview window
+    @ivar preview_widget: Widget to be represented
+    """
     def __init__(self):
         self.preview_button = None
         self.preview_widget = None
@@ -1038,6 +1103,9 @@ class PreviewMixin:
         panel.SetScrollbars(1, 5, 1, int(math.ceil(h/5.0)))
 
     def preview(self, event):
+        """\
+        Create a preview of the selected widget
+        """
         #print 'frame class _> ', self.klass
         if self.preview_widget is None:
             self.preview_widget = common.app_tree.app.preview(self)
@@ -1048,6 +1116,11 @@ class PreviewMixin:
             self.preview_widget.Close()
 
     def preview_is_visible(self):
+        """\
+        True if the L{preview_button} is created
+
+        @rtype: Boolean
+        """
         return self.preview_widget is not None
 
 # end of class PreviewMixin
@@ -1059,7 +1132,7 @@ class TopLevelBase(WindowBase, PreviewMixin):
     """
     _is_toplevel = True
     _custom_base_classes = True
-    
+
     def __init__(self, name, klass, parent, id, property_window, show=True,
                  has_title=True, title=None):
         WindowBase.__init__(self, name, klass, parent, id, property_window,
@@ -1152,7 +1225,7 @@ class TopLevelBase(WindowBase, PreviewMixin):
 ##             self.properties['title'].display(panel)
 ##             sizer_tmp.Add(self.properties['title'].panel, 0, wxEXPAND)
         PreviewMixin.create_properties(self)
-            
+
     def get_title(self):
         return self.title
 
@@ -1195,10 +1268,15 @@ class TopLevelBase(WindowBase, PreviewMixin):
             self.sizer.refresh()
 
     def set_name(self, name):
-        if not misc.streq(self.name, name):
-            common.app_tree.app.update_top_window_name(self.name, name)
+        oldname = self.name
+
+        # check and set name
         WindowBase.set_name(self, name)
 
+        # update top window name
+        if not misc.streq(oldname, self.name):
+            common.app_tree.app.update_top_window_name(oldname, self.name)
+
     def delete(self, *args):
         if self.preview_widget is not None:
             self.preview_widget.Destroy()
