@@ -131,6 +131,24 @@ _encode = common._encode_from_xml
 def bound(number, lower, upper):
     return min(max(lower, number), upper)
 
+
+def capitalize(string):
+    """\
+    Return string with first character capitalised. Some acronym like
+    XML, XRC.
+
+    @param string: String to convert
+    @type string:  String (plain or unicode)
+
+    @note: Be carefully it possibly breaks i18n.
+    """
+    # Don't capitalise those terms
+    if string.upper() in ['XML', 'XRC', 'URL']:
+        return string.upper()
+
+    return string.capitalize()
+
+
 def color_to_string(color):
     """\
     returns the hexadecimal string representation of the given color:
@@ -140,6 +158,7 @@ def color_to_string(color):
     return '#' + reduce(operator.add, ['%02x' % bound(c, 0, 255) for c in
                                        color.Get()])
 
+
 def string_to_color(color):
     """\
     returns the wxColour which corresponds to the given
@@ -149,7 +168,20 @@ def string_to_color(color):
     if len(color) != 7: raise ValueError
     return apply(wx.Colour, [int(color[i:i+2], 16) for i in range(1, 7, 2)])
 
-    
+
+def format_for_version(version):
+    """\
+    Return the version information in C{for_version} in a string.
+
+    Example::
+        >>> print format_for_version((2, 8))
+        2.8
+
+    @see: L{wxglade.codegen.BaseCodeWriter.for_version}
+    """
+    return '%s.%s' % version
+
+
 def get_toplevel_parent(obj):
     if not isinstance(obj, wx.Window): window = obj.widget
     else: window = obj
@@ -207,8 +239,6 @@ def append_item(menu, id, text, xpm_file_or_artid=None):
     if use_menu_icons is None:
         import config
         use_menu_icons = config.preferences.use_menu_icons
-    if wx.Platform == '__WXGTK__' and wx.VERSION == (2, 4, 1, 2, ''):
-        use_menu_icons = 0
     item = wx.MenuItem(menu, id, text)
     if wx.Platform == '__WXMSW__':
         path = 'msw/'
@@ -329,8 +359,7 @@ def import_name(module_path, name):
         finally:
             mfile.close()
     except ImportError:
-        import traceback
-        traceback.print_exc()
+        common.message.exception(_('Internal Error'))
         return None
     return vars(module)[name]
 
@@ -383,31 +412,6 @@ def wxstr(s, encoding=None):
 hidden_property_panel = None
 
 
-#------------------------------------------------------------------------------
-
-try:
-    enumerate = enumerate
-except NameError:
-    class enumerate(object):
-        """\
-        Python 2.2.x replacement for the `enumerate' builtin.
-        """
-        def __init__(self, iterable):
-            self.iterable = iterable
-            self.index = -1
-
-        def __iter__(self):
-            self.iterable = iter(self.iterable)
-            return self
-
-        def next(self):
-            val = self.iterable.next()
-            self.index += 1
-            return self.index, val
-
-    # end of class enumerate
-
-
 def design_title(title):
     return _('<Design> - ') + title
 
@@ -434,8 +438,7 @@ def get_xpm_bitmap(path):
 ##                     for d in data: print d
                     bmp = wx.BitmapFromXPMData(data)
                 except:
-                    import traceback
-                    traceback.print_exc()
+                    common.message.exception(_('Internal Error'))
                     bmp = wx.NullBitmap
     else:
         bmp = wx.Bitmap(path, wx.BITMAP_TYPE_XPM)
