@@ -133,7 +133,7 @@ class Tree:
     def _find_toplevel(self, node):
         assert node is not None, _("None node in _find_toplevel")
         if node.parent is self.root:
-            return node.parent
+            return node
         while node.parent is not self.root:
             node = node.parent
         return node
@@ -450,8 +450,7 @@ class WidgetTree(wx.TreeCtrl, Tree):
             except AttributeError:
                 pass
             except Exception:
-                import traceback
-                traceback.print_exc()
+                common.message.exception(_('Internal Error'))
 
     def popup_menu(self, event):
         node = self._find_item_by_pos(*event.GetPosition())
@@ -472,8 +471,7 @@ class WidgetTree(wx.TreeCtrl, Tree):
             event.m_x, event.m_y = x, y
             item.popup_menu(event)
         except AttributeError:
-            import traceback;
-            traceback.print_exc()
+            common.message.exception(_('Internal Error'))
 
     def expand(self, node=None, yes=True):
         """\
