@@ -1,7 +1,7 @@
 # perl_codegen.py : perl generator functions for wxListCtrl objects
-# $Id: perl_codegen.py,v 1.4 2005/08/15 07:41:03 crazyinsomniac Exp $
 #
 # Copyright (c) 2002-2004 D.H. aka crazyinsomniac on sourceforge.net
+#
 # License: MIT (see license.txt)
 # THIS PROGRAM COMES WITH NO WARRANTY
 
@@ -27,7 +27,7 @@ class PerlCodeGenerator:
         if id_name:
             init.append(id_name)
 
-        klass = obj.base;
+        klass = obj.base
         if klass != obj.klass:
             klass = obj.klass
         else:
