@@ -1,16 +1,16 @@
 # menubar.py: wxMenuBar objects
-# $Id: menubar.py,v 1.27 2007/03/27 07:01:57 agriggio Exp $
 #
 # Copyright (c) 2002-2007 Alberto Griggio <agriggio@users.sourceforge.net>
+#
 # License: MIT (see license.txt)
 # THIS PROGRAM COMES WITH NO WARRANTY
 
 import wx
-import common, math, misc
+import common, misc
 from tree import Tree
 from MenuTree import *
 from widget_properties import *
-from edit_windows import EditBase, TopLevelBase, PreviewMixin
+from edit_windows import EditBase, PreviewMixin
 
 
 class MenuItemDialog(wx.Dialog):
@@ -112,10 +112,7 @@ class MenuItemDialog(wx.Dialog):
         self.help_str.SetSize((150, -1))
         self.event_handler.SetSize((150, -1))
         szr = wx.FlexGridSizer(0, 2)
-        if misc.check_wx_version(2, 5, 2):
-            flag = wx.FIXED_MINSIZE
-        else:
-            flag = 0
+        flag = wx.FIXED_MINSIZE
         label_flag = wx.ALIGN_CENTER_VERTICAL
         szr.Add(wx.StaticText(self, -1, _("Id   ")), flag=label_flag)
         szr.Add(self.id, flag=flag)
@@ -156,7 +153,7 @@ class MenuItemDialog(wx.Dialog):
         self.SetSizer(sizer)
         sizer.Fit(self)
         self.SetSize((-1, 350))
-        self.CenterOnParent()
+        self.CenterOnScreen()
 
     def _enable_fields(self, enable=True):
         for s in (self.label, self.id, self.name, self.help_str,
@@ -565,6 +562,11 @@ class EditMenuBar(EditBase, PreviewMixin):
             self._mb = wx.MenuBar()
             self.widget.SetMenuBar(self._mb)
             self.widget.SetBackgroundColour(self._mb.GetBackgroundColour())
+            import os
+            icon = wx.EmptyIcon()
+            xpm = os.path.join(common.icons_path, 'menubar.xpm')
+            icon.CopyFromBitmap(misc.get_xpm_bitmap(xpm))
+            self.widget.SetIcon(icon)
             wx.EVT_CLOSE(self.widget, lambda e: self.hide_widget())
         wx.EVT_LEFT_DOWN(self.widget, self.on_set_focus)
         self.set_menus(self.menus) # show the menus
@@ -645,10 +647,6 @@ class EditMenuBar(EditBase, PreviewMixin):
                 self.widget = None
             else:
                 if self.parent.widget:
-                    if wx.Platform == '__WXGTK__' and \
-                           not misc.check_wx_version(2, 5):
-                        self.widget.Reparent(EditMenuBar.__hidden_frame)
-                        self.widget.Hide()
                     self.parent.widget.SetMenuBar(None)
         else:
             if self.widget:
@@ -664,10 +662,10 @@ class EditMenuBar(EditBase, PreviewMixin):
                 REMOVE_ID, HIDE_ID = [wx.NewId() for i in range(2)]
                 self._rmenu = misc.wxGladePopupMenu(self.name)
                 misc.append_item(self._rmenu, REMOVE_ID, _('Remove\tDel'),
-                                 'remove.xpm')
+                                 wx.ART_DELETE)
                 misc.append_item(self._rmenu, HIDE_ID, _('Hide'))
                 def bind(method):
-                    return lambda e: misc.wxCallAfter(method)
+                    return lambda e: wx.CallAfter(method)
                 wx.EVT_MENU(self.widget, REMOVE_ID, bind(self.remove))
                 wx.EVT_MENU(self.widget, HIDE_ID, bind(self.hide_widget))
                 
@@ -732,13 +730,13 @@ class EditMenuBar(EditBase, PreviewMixin):
                         self.curr_index = -1
                         pass
 ##                         from xml_parse import XmlParsingError
-##                         raise XmlParsingError, "invalid menu item attribute"
+##                         raise XmlParsingError, _("invalid menu item attribute")
             def end_elem(self, name):
                 if name == 'item':
                     try: cm = self.curr_menu[-1]
                     except IndexError:
                         from xml_parse import XmlParsingError
-                        raise XmlParsingError, "menu item outside a menu"
+                        raise XmlParsingError, _("menu item outside a menu")
                     cm[0].children.append(self.curr_item)
                     self.curr_item.parent = cm[0]
                 elif name == 'menu':
@@ -770,7 +768,7 @@ def builder(parent, sizer, pos, number=[0]):
                 if not number[0]: self.klass = 'MyMenuBar'
                 else: self.klass = 'MyMenuBar%s' % number[0]
                 number[0] += 1
-            klass_prop = TextProperty(self, 'class', self)
+            klass_prop = TextProperty(self, 'class', self, label=_('class'))
             szr = wx.BoxSizer(wx.VERTICAL)
             szr.Add(klass_prop.panel, 0, wx.EXPAND)
             sz2 = wx.BoxSizer(wx.HORIZONTAL)
@@ -782,6 +780,7 @@ def builder(parent, sizer, pos, number=[0]):
             szr.Fit(self)
             if self.GetBestSize()[0] < 150:
                 self.SetSize((150, -1))
+            self.CenterOnScreen()
 
         def undo(self):
             if number[0] > 0:
