@@ -1,9 +1,9 @@
-# notebook.py: wxNotebook objects
-#
-# Copyright (c) 2002-2007 Alberto Griggio <agriggio@users.sourceforge.net>
-#
-# License: MIT (see license.txt)
-# THIS PROGRAM COMES WITH NO WARRANTY
+"""\
+wxNotebook objects
+
+@copyright: 2002-2007 Alberto Griggio <agriggio@users.sourceforge.net>
+@license: MIT (see license.txt) - THIS PROGRAM COMES WITH NO WARRANTY
+"""
 
 import wx
 import common
@@ -12,6 +12,7 @@ from tree import Tree
 from widget_properties import *
 from edit_windows import ManagedBase
 from edit_sizers.edit_sizers import Sizer, SizerSlot
+from xml_parse import XmlParsingError
 
 try:
     from panel import EditPanel
@@ -19,6 +20,7 @@ try:
 except ImportError:
     _has_panel = False
 
+
 def _ugly_hack_for_win32_notebook_bug(notebook_widget):
     """\
     The name should say all. The problem is hard to explain, so let me
@@ -44,8 +46,8 @@ def _ugly_hack_for_win32_notebook_bug(notebook_widget):
     for i in range(notebook_widget.GetPageCount()):
         notebook_widget.GetPage(i).Hide()
     notebook_widget.GetPage(index_ok).Show()
-    
-    
+
+
 class NotebookVirtualSizer(Sizer):
     '''\
     "Virtual sizer" responsible for the management of the pages of a Notebook.
@@ -53,7 +55,7 @@ class NotebookVirtualSizer(Sizer):
     def __init__(self, *args, **kwds):
         Sizer.__init__(self, *args, **kwds)
         self._itempos = 0
-    
+
     def set_item(self, pos, option=None, flag=None, border=None, size=None,
                  force_layout=True):
         """\
@@ -80,14 +82,20 @@ class NotebookVirtualSizer(Sizer):
         if self.window.sizer is not None:
             self.window.sizer.set_item(
                 self.window.pos, size=self.window.widget.GetBestSize())
-            
+
     def add_item(self, item, pos=None, option=0, flag=0, border=0, size=None,
                  force_layout=True):
         """\
         Adds an item to self.window.
         """
         #print 'pos:', pos, 'item.name:', item.name
-        self.window.tabs[pos-1][1] = item
+        try:
+            self.window.tabs[pos - 1][1] = item
+        except IndexError:
+            raise XmlParsingError(
+                _('Notebook widget "%s" does not have any tabs!') % \
+                self.window.name
+                )
         item._dont_destroy = True
 
     def free_slot(self, pos, force_layout=True):
@@ -99,31 +107,31 @@ class NotebookVirtualSizer(Sizer):
         slot = SizerSlot(self.window, self, pos)
         #print 'free:', slot, slot.pos, pos
         slot.show_widget(True)
-        pos = pos-1
+        pos = pos - 1
         label, item = self.window.tabs[pos]
         self.window.widget.RemovePage(pos)
         self.window.widget.InsertPage(pos, slot.widget, label)
         self.window.widget.SetSelection(pos)
-    
+
     def get_itempos(self, attrs):
         """\
         Get position of sizer item (used in xml_parse)
         """
         self._itempos += 1
         return self._itempos
-    
+
     def is_virtual(self):
         return True
 
 # end of class NotebookVirtualSizer
 
 
-class NotebookPagesProperty(GridProperty):      
+class NotebookPagesProperty(GridProperty):
     def write(self, outfile, tabs):
         from xml.sax.saxutils import escape, quoteattr
         write = outfile.write
         write('    ' * tabs + '<tabs>\n')
-        tab_s = '    ' * (tabs+1)
+        tab_s = '    ' * (tabs + 1)
         import widget_properties
         value = self.get_value()
         for i in range(len(value)):
@@ -132,8 +140,10 @@ class NotebookPagesProperty(GridProperty):
             window = None
             try:
                 t = self.owner.tabs[i]
-                if t[0] == val[0]: window = t[1]
-            except: pass
+                if t[0] == val[0]:
+                    window = t[1]
+            except:
+                pass
             if window:
                 write('%s<tab window=%s>' % (tab_s, quoteattr(window.name)))
                 write(v)
@@ -173,28 +183,69 @@ class TabsHandler:
 class EditNotebook(ManagedBase):
 
     _custom_base_classes = True
+    notebook_number = 1
+    """\
+    @cvar: Next free number for notebook names. The number is continuously.
+
+    Each notebook gets an own number. It's very useful for labeling
+    panes. Deleting notebooks won't decrease this number.
+
+    @see: L{self.next_notebook_name()}
+    @type: Integer
+    @note: Use only C{+=1} for increasing!
+    """
+
+    pane_number = 1
+    """\
+    @ivar: Free number for pane names. This number is is continuously.
+
+    Each pane get an own number. It's very useful for labelung. Deleting
+    oanes won't decrease this number.
+
+    @see: L{self.next_pane_name()}
+    @type: Integer
+    """
+
     events = ['EVT_NOTEBOOK_PAGE_CHANGED', 'EVT_NOTEBOOK_PAGE_CHANGING']
-    
+
     def __init__(self, name, parent, id, style, sizer, pos,
                  property_window, show=True):
         """\
         Class to handle wxNotebook objects
         """
+        # create new and (still) unused notebook name
+        if not name:
+            name = self.next_notebook_name()
+
+        # Increase number of created notebooks
+        EditNotebook.notebook_number += 1
+
         ManagedBase.__init__(self, name, 'wxNotebook', parent, id, sizer,
                              pos, property_window, show=show)
+
         self.virtual_sizer = NotebookVirtualSizer(self)
         self._is_removing_pages = False
         self.style = style
-        self.tabs = [ ['tab1', None] ] # list of pages of this notebook
-                                       # (actually a list of
-                                       # 2-list label, window)
+        self.tabs = [['tab1', None]]  # list of pages of this notebook
+                                      # (actually a list of
+                                      # 2-list label, window)
 
         self.access_functions['style'] = (self.get_tab_pos, self.set_tab_pos)
-        self.properties['style'] = HiddenProperty(self, 'style', label=_("style"))
+        self.properties['style'] = HiddenProperty(
+            self,
+            'style',
+            label=_("style"),
+            )
         self.access_functions['tabs'] = (self.get_tabs, self.set_tabs)
         tab_cols = [('Tab label', GridProperty.STRING)]
-        self.properties['tabs'] = NotebookPagesProperty(self, 'tabs', None,
-                                                        tab_cols, label=_("tabs"))
+        self.properties['tabs'] = NotebookPagesProperty(
+            self,
+            'tabs',
+            None,
+            tab_cols,
+            label=_("tabs"),
+            can_remove_last=False,
+            )
         del tab_cols
         self.nb_sizer = None
         self._create_slots = False
@@ -206,8 +257,15 @@ class EditNotebook(ManagedBase):
             self, 'no_custom_class',
             label=_("Don't generate code for this custom class"))
 
+        # first pane should have number 1
+        self.pane_number = 1
+
     def create_widget(self):
-        self.widget = wx.Notebook(self.parent.widget, self.id, style=self.style)
+        self.widget = wx.Notebook(
+            self.parent.widget,
+            self.id,
+            style=self.style,
+            )
 
     def show_widget(self, yes):
         ManagedBase.show_widget(self, yes)
@@ -226,13 +284,17 @@ class EditNotebook(ManagedBase):
 
     def create_properties(self):
         ManagedBase.create_properties(self)
-        panel = wx.ScrolledWindow(self.notebook, -1, style=wx.TAB_TRAVERSAL)
+        panel = wx.ScrolledWindow(
+            self.notebook,
+            wx.ID_ANY,
+            style=wx.TAB_TRAVERSAL,
+            )
         self.properties['no_custom_class'].display(panel)
         self.properties['tabs'].display(panel)
         sizer = wx.BoxSizer(wx.VERTICAL)
         sizer.Add(self.properties['no_custom_class'].panel, 0,
-                  wx.ALL|wx.EXPAND, 3)
-        sizer.Add(self.properties['tabs'].panel, 1, wx.ALL|wx.EXPAND, 3)
+                  wx.ALL | wx.EXPAND, 3)
+        sizer.Add(self.properties['tabs'].panel, 1, wx.ALL | wx.EXPAND, 3)
         panel.SetAutoLayout(True)
         panel.SetSizer(sizer)
         sizer.Fit(panel)
@@ -246,7 +308,7 @@ class EditNotebook(ManagedBase):
     def _add_tab(self, window, pos):
         if window is None:
             window = SizerSlot(self, self.virtual_sizer, pos)
-            self.tabs[pos-1][1] = window
+            self.tabs[pos - 1][1] = window
         else:
             window._dont_destroy = True
             node = Tree.Node(window)
@@ -262,7 +324,7 @@ class EditNotebook(ManagedBase):
                 pass
 
     def get_tabs(self):
-        return [ [n] for n, w in self.tabs ]
+        return [[n] for n, w in self.tabs]
 
     def set_tabs(self, tabs):
         delta = len(self.tabs) - len(tabs)
@@ -275,27 +337,29 @@ class EditNotebook(ManagedBase):
                     self.widget.RemovePage(i)
                     window.remove(False)
             del self.tabs[i:]
-            if self.widget: self.widget.SetSelection(0)
+            if self.widget:
+                self.widget.SetSelection(0)
             self._is_removing_pages = False
         elif delta < 0:
             # we have to add some pages
-            number = len(self.tabs)+1
-            while common.app_tree.has_name(self.name + '_pane_%s' % number):
-                number += 1
             pos = len(self.tabs)
             for i in range(-delta):
                 self.tabs.append(['', None])
                 pos += 1
                 if _has_panel:
-                    window = EditPanel(self.name + '_pane_%s' % number, self,
-                                       -1, self.virtual_sizer, pos,
-                                       self.property_window)
+                    window = EditPanel(
+                        self.next_pane_name(),
+                        self,
+                        wx.ID_ANY,
+                        self.virtual_sizer,
+                        pos,
+                        self.property_window,
+                        )
                     self._add_tab(window, pos)
                 else:
                     self._add_tab(None, pos)
-                number += 1
             if self.widget:
-                self.widget.SetSelection(self.widget.GetPageCount()-1)
+                self.widget.SetSelection(self.widget.GetPageCount() - 1)
         # finally, we must update the labels of the tabs
         for i in range(len(tabs)):
             tt = misc.wxstr(tabs[i][0])
@@ -309,7 +373,8 @@ class EditNotebook(ManagedBase):
         ManagedBase.delete(self)
 
     def get_property_handler(self, name):
-        if name == 'tabs': return TabsHandler(self)
+        if name == 'tabs':
+            return TabsHandler(self)
         return ManagedBase.get_property_handler(self, name)
 
     def find_page(self, page):
@@ -317,21 +382,24 @@ class EditNotebook(ManagedBase):
         returns the index of the given page in the notebook, or -1 if the page
         cannot be found
         """
-        if not self.widget: return -1
+        if not self.widget:
+            return -1
         for i in range(len(self.tabs)):
             if self.tabs[i][1] is page:
-                if i < self.widget.GetPageCount(): return i
-                else: return -1
+                if i < self.widget.GetPageCount():
+                    return i
+                else:
+                    return -1
         return -1
 
-    def get_tab_pos(self): 
-        styles = { wx.NB_LEFT: 'wxNB_LEFT', wx.NB_RIGHT: 'wxNB_RIGHT',
-                   wx.NB_BOTTOM: 'wxNB_BOTTOM' }
+    def get_tab_pos(self):
+        styles = {wx.NB_LEFT: 'wxNB_LEFT', wx.NB_RIGHT: 'wxNB_RIGHT',
+                  wx.NB_BOTTOM: 'wxNB_BOTTOM'}
         return styles.get(self.style, '0')
-    
+
     def set_tab_pos(self, value):
-        styles = { 'wxNB_LEFT': wx.NB_LEFT, 'wxNB_RIGHT': wx.NB_RIGHT,
-                   'wxNB_BOTTOM': wx.NB_BOTTOM }
+        styles = {'wxNB_LEFT': wx.NB_LEFT, 'wxNB_RIGHT': wx.NB_RIGHT,
+                  'wxNB_BOTTOM': wx.NB_BOTTOM}
         self.style = styles.get(value, 0)
 
     def get_no_custom_class(self):
@@ -340,8 +408,34 @@ class EditNotebook(ManagedBase):
     def set_no_custom_class(self, value):
         self.no_custom_class = bool(int(value))
 
+    def next_notebook_name(self):
+        """\
+        Return new and (still) unused notebook name
+
+        @see: L{self.notebook_number}
+        """
+        while True:
+            name = 'notebook_%d' % EditNotebook.notebook_number
+            if not common.app_tree.has_name(name):
+                break
+            EditNotebook.notebook_number += 1
+        return name
+
+    def next_pane_name(self):
+        """\
+        Return new and (still) unused pane name
+
+        @see: L{self.pane_number}
+        """
+        while True:
+            pane_name = "%s_pane_%d" % (self.name, self.pane_number)
+            self.pane_number += 1
+            if not common.app_tree.has_name(pane_name):
+                break
+        return pane_name
+
 # end of class EditNotebook
-        
+
 
 def builder(parent, sizer, pos, number=[1]):
     """\
@@ -349,46 +443,61 @@ def builder(parent, sizer, pos, number=[1]):
     """
     class Dialog(wx.Dialog):
         def __init__(self):
-            wx.Dialog.__init__(self, None, -1, _('Select tab placement'))
-            self.styles = [ 0, wx.NB_BOTTOM, wx.NB_LEFT, wx.NB_RIGHT ]
+            wx.Dialog.__init__(
+                self,
+                None,
+                wx.ID_ANY,
+                _('Select tab placement'),
+                )
+            self.styles = [0, wx.NB_BOTTOM, wx.NB_LEFT, wx.NB_RIGHT]
             self.style = 0
-            prop = RadioProperty(self, 'tab_placement', self,
-                                 [_('Top'), _('Bottom'), _('Left'), _('Right')],
-                                 columns=2, label=_('tab_placement'))
+            prop = RadioProperty(
+                self,
+                'tab_placement',
+                self,
+                [_('Top'), _('Bottom'), _('Left'), _('Right')],
+                columns=2,
+                label=_('tab_placement'),
+                )
             szr = wx.BoxSizer(wx.VERTICAL)
-            szr.Add(prop.panel, 0, wx.ALL|wx.EXPAND, 10)
+            szr.Add(prop.panel, 0, wx.ALL | wx.EXPAND, 10)
             btn = wx.Button(self, wx.ID_OK, _('OK'))
             btn.SetDefault()
-            szr.Add(btn, 0, wx.BOTTOM|wx.ALIGN_CENTER, 10)
+            szr.Add(btn, 0, wx.BOTTOM | wx.ALIGN_CENTER, 10)
             self.SetAutoLayout(True)
             self.SetSizer(szr)
             szr.Fit(self)
             self.CenterOnScreen()
+
         def __getitem__(self, value):
-            def set_style(s): self.style = self.styles[s]
+            def set_style(s):
+                self.style = self.styles[s]
             return (lambda: self.style, set_style)
+
     # end of inner class
 
     dialog = Dialog()
     dialog.ShowModal()
-    name = 'notebook_%d' % number[0]
-    while common.app_tree.has_name(name):
-        number[0] += 1
-        name = 'notebook_%d' % number[0]
-    window = EditNotebook(name, parent, wx.NewId(), dialog.style,
+    window = EditNotebook(None, parent, wx.ID_ANY, dialog.style,
                           sizer, pos, common.property_panel, show=False)
     if _has_panel:
-        pane1 = EditPanel(name + '_pane_1', window, wx.NewId(),
-                          window.virtual_sizer, 1, common.property_panel)
+        pane1 = EditPanel(
+            window.next_pane_name(),
+            window,
+            wx.ID_ANY,
+            window.virtual_sizer,
+            1,
+            common.property_panel,
+            )
 
     node = Tree.Node(window)
     window.node = node
     window.virtual_sizer.node = node
-    
+
     window.set_option(1)
     window.set_flag("wxEXPAND")
     window.show_widget(True)
-    common.app_tree.insert(node, sizer.node, pos-1)
+    common.app_tree.insert(node, sizer.node, pos - 1)
 
     if _has_panel:
         window._add_tab(pane1, 1)
@@ -400,12 +509,13 @@ def xml_builder(attrs, parent, sizer, sizeritem, pos=None):
     """\
     factory to build EditNotebook objects from an xml file
     """
-    from xml_parse import XmlParsingError
-    try: name = attrs['name']
-    except KeyError: raise XmlParsingError, _("'name' attribute missing")
+    try:
+        name = attrs['name']
+    except KeyError:
+        raise XmlParsingError(_("'name' attribute missing"))
     if not sizer or not sizeritem:
-        raise XmlParsingError, _("sizer or sizeritem object cannot be None")
-    window = EditNotebook(name, parent, wx.NewId(), 0, sizer, pos,
+        raise XmlParsingError(_("sizer or sizeritem object cannot be None"))
+    window = EditNotebook(name, parent, wx.ID_ANY, 0, sizer, pos,
                           common.property_panel, True)
     window._create_slots = True
 
@@ -413,8 +523,10 @@ def xml_builder(attrs, parent, sizer, sizeritem, pos=None):
                    border=sizeritem.border)
     node = Tree.Node(window)
     window.node = node
-    if pos is None: common.app_tree.add(node, sizer.node)
-    else: common.app_tree.insert(node, sizer.node, pos-1)
+    if pos is None:
+        common.app_tree.add(node, sizer.node)
+    else:
+        common.app_tree.insert(node, sizer.node, pos - 1)
     return window
 
 
@@ -427,4 +539,3 @@ def initialize():
     common.widgets_from_xml['EditNotebook'] = xml_builder
 
     return common.make_object_button('EditNotebook', 'icons/notebook.xpm')
-    
