@@ -186,6 +186,10 @@ class XmlWidgetBuilder(XmlParser):
             if overwrite:
                 app.overwrite = True
                 app.overwrite_prop.set_value(True)
+            else:
+                app.overwrite = False
+                app.overwrite_prop.set_value(False)
+
             try:
                 use_new_namespace = int(attrs['use_new_namespace'])
             except (KeyError, ValueError):
@@ -672,8 +676,11 @@ class CodeWriter(XmlParser):
                 if os.path.isdir(self.out_path):
                     raise errors.WxgOutputPathIsDirectory(self.out_path)
                 directory = os.path.dirname(self.out_path)
-                if directory and not os.access(directory, os.W_OK):
-                    raise errors.WxgOutputDirectoryNotWritable(directory)
+                if directory:
+                    if not os.path.isdir(directory):
+                        raise errors.WxgOutputDirectoryNotExist(directory)
+                    if not os.access(directory, os.W_OK):
+                        raise errors.WxgOutputDirectoryNotWritable(directory)
 
             # initialize the writer
             self.code_writer.initialize(attrs)
